@@ -1,9 +1,8 @@
 from abc import ABC
-from typing import Any
 
 from requests import Response
 
-from ..client import HttpClient, HttpMethod
+from ..client import GenericTypedDict, HttpClient, HttpMethod
 
 
 class Resource(ABC):
@@ -20,14 +19,14 @@ class Resource(ABC):
             self.base_path is not None
         ), "base_path must be defined on resource"
 
-    def create(self, data: dict[str, Any]) -> Response:
+    def create(self, data: GenericTypedDict) -> Response:
         return self._client.call_api(
             HttpMethod.POST,
             self.base_path,
             data=data,
         )
 
-    def update(self, object_id: str, data: dict[str, Any]) -> Response:
+    def update(self, object_id: str, data: GenericTypedDict) -> Response:
         return self._client.call_api(
             HttpMethod.PUT,
             path=f"{self.base_path}/{object_id}",
@@ -40,11 +39,11 @@ class Resource(ABC):
             path=f"{self.base_path}/{object_id}",
         )
 
-    def list(self, params: dict[str, Any] | None = None) -> Response:
+    def list(self, params: GenericTypedDict | None = None) -> Response:
         return self._client.call_api(
             HttpMethod.GET,
             path=self.base_path,
-            params=params,
+            params=params,  # type: ignore
         )
 
     def retrieve(self, object_id: str) -> Response:
